@@ -3,10 +3,11 @@ package MooX::SugarFactory;
 use strictures 2;
 use Import::Into;
 use MooX::BuildClass;
+use MooX::BuildRole;
 use Constructor::SugarLibrary ();
 use Throwable::SugarFactory::Utils '_getglob';
 
-our $VERSION = '0.152090'; # VERSION
+our $VERSION = '0.152091'; # VERSION
 
 # ABSTRACT: build a library of syntax-sugared Moo classes
 
@@ -25,13 +26,21 @@ our $VERSION = '0.152090'; # VERSION
 
 
 sub import {
+    my ( $class ) = @_;
     Constructor::SugarLibrary->import::into( 1 );
     my $factory = caller;
-    *{ _getglob $factory, "class" } = sub {
+    *{ _getglob $factory, $_ } = $class->_creator_with( $factory, $_ )
+      for qw( class role );
+}
+
+sub _creator_with {
+    my ( $class, $factory, $type ) = @_;
+    my $create = \&{ "Build" . ucfirst $type };
+    sub {
         my ( $spec, @args ) = @_;
         my ( $class ) = split /->/, $spec;
         my $build = $factory->can( "BUILDARGS" ) || sub { shift; @_ };
-        BuildClass $class, $build->( $class, @args );
+        $create->( $class, $build->( $class, @args ) );
         $factory->sweeten_meth( $spec );
         return;
     };
@@ -49,7 +58,7 @@ MooX::SugarFactory - build a library of syntax-sugared Moo classes
 
 =head1 VERSION
 
-version 0.152090
+version 0.152091
 
 =head1 SYNOPSIS
 
@@ -63,11 +72,12 @@ Declare classes in a library that will export sugar.
         has => [ more => ( is => 'ro' ) ],
     );
     
-    class "My::Moose::Thing" => (
+    class "My::Moose::ThingRole" => (
         has     => [ contains => ( is => 'ro' ) ],
-        has     => [ meta     => ( is => 'ro' ) ],
-        extends => Object(),
+        has     => [ metaa    => ( is => 'ro' ) ],
     );
+    
+    class "My::Moose::Thing" => ( with => ThingRole(), extends => Object() );
 
 Use class library to export sugar for object construction and class checking.
 
@@ -82,6 +92,7 @@ Use class library to export sugar for object construction and class checking.
       plus => "some", more => "data";
     
     die if !$obj2->isa( Thing );
+    die if !$obj2->does( ThingRole );
     die if !$obj2->isa( Object );
     die if !$obj2->meta eq "data";
 
